#' @details
#' \tabular{ll}{
#'  \strong{Package:} \tab khroma \cr
#'  \strong{Type:} \tab Package \cr
#'  \strong{Version:} \tab 1.1.1 \cr
#'  \strong{Date:} \tab 2019-04-10 \cr
#'  \strong{License:} \tab GPL-3 \cr
#'  \strong{DOI:} \tab \href{https://doi.org/10.5281/zenodo.1472077}{10.5281/zenodo.1472077}
#' }
#' @author
#' \strong{Full list of authors and contributors} (alphabetic order)
#'  \tabular{ll}{
#'   Nicolas Frerebeau \tab \emph{IRAMAT-CRP2A, Université Bordeaux Montaigne, France} \cr
#'   Brice Lebrun \tab \emph{CEREGE, Aix-Marseille Université, France}
#'  }
#'
#' \strong{Package maintainer}
#'
#' Nicolas Frerebeau\cr
#' \email{nicolas.frerebeau@@u-bordeaux-montaigne.fr}
#'
#' IRAMAT-CRP2A (UMR 5060)\cr
#' Maison de l'Archéologie\cr
#' Universite Bordeaux Montaigne\cr
#' F-33607 Pessac cedex\cr
#' France
#' @name khroma-package
#' @aliases khroma-package khroma
#' @docType package
#' @keywords internal
"_PACKAGE"
